{% extends "base.html" %}
{% block movies %}
{% for movie in movies %}
<tr>
    <td>
        <h3>{{ movie.title }}</h3>
        <p style="text-align: center"><img class="banner" src="{{ movie.image }}" alt="Estreno"></p>
        {{ movie.info }}
        <p class="callout">
            <strong>Madrid</strong><br>{{ movie.purchase_info }}<br><a href="{{ movie.purchase_link }}">Comprar entradas &raquo;</a>
        </p>
    </td>
</tr>
{% endfor %}
{% endblock %}
